@@ -10,7 +10,9 @@ import publication
 
 import constructs._jsii
 
-__jsii_assembly__ = jsii.JSIIAssembly.load("monocdk-experiment", "1.49.1", __name__[0:-6], "monocdk-experiment@1.49.1.jsii.tgz")
+__jsii_assembly__ = jsii.JSIIAssembly.load(
+    "monocdk-experiment", "1.50.0", __name__[0:-6], "monocdk-experiment@1.50.0.jsii.tgz"
+)
 
 __all__ = [
     "__jsii_assembly__",
