@@ -10,14 +10,42 @@ import publication
 
 from .._jsii import *
 
-from .. import (Resource as _Resource_884d0774, Construct as _Construct_f50a3f53, CfnResource as _CfnResource_7760e8e4, FromCloudFormationOptions as _FromCloudFormationOptions_5f49f6f1, TreeInspector as _TreeInspector_154f5999, TagManager as _TagManager_2508893f, IResolvable as _IResolvable_9ceae33e, IInspectable as _IInspectable_051e6ed8, CfnTag as _CfnTag_b4661f1a, IResource as _IResource_72f7ee7e)
-from ..aws_iam import (IRole as _IRole_e69bbae4)
-from ..aws_route53 import (IHostedZone as _IHostedZone_59ffab76)
+from .. import (
+    Resource as _Resource_884d0774,
+    Construct as _Construct_f50a3f53,
+    CfnResource as _CfnResource_7760e8e4,
+    IResolvable as _IResolvable_9ceae33e,
+    CfnTag as _CfnTag_b4661f1a,
+    FromCloudFormationOptions as _FromCloudFormationOptions_5f49f6f1,
+    ICfnFinder as _ICfnFinder_3b168f30,
+    TreeInspector as _TreeInspector_154f5999,
+    TagManager as _TagManager_2508893f,
+    IInspectable as _IInspectable_051e6ed8,
+    IResource as _IResource_72f7ee7e,
+)
+from ..aws_iam import IRole as _IRole_e69bbae4
+from ..aws_route53 import IHostedZone as _IHostedZone_59ffab76
 
 
-@jsii.data_type(jsii_type="monocdk-experiment.aws_certificatemanager.CertificateProps", jsii_struct_bases=[], name_mapping={'domain_name': 'domainName', 'subject_alternative_names': 'subjectAlternativeNames', 'validation_domains': 'validationDomains', 'validation_method': 'validationMethod'})
-class CertificateProps():
-    def __init__(self, *, domain_name: str, subject_alternative_names: typing.Optional[typing.List[str]]=None, validation_domains: typing.Optional[typing.Mapping[str, str]]=None, validation_method: typing.Optional["ValidationMethod"]=None) -> None:
+@jsii.data_type(
+    jsii_type="monocdk-experiment.aws_certificatemanager.CertificateProps",
+    jsii_struct_bases=[],
+    name_mapping={
+        "domain_name": "domainName",
+        "subject_alternative_names": "subjectAlternativeNames",
+        "validation_domains": "validationDomains",
+        "validation_method": "validationMethod",
+    },
+)
+class CertificateProps:
+    def __init__(
+        self,
+        *,
+        domain_name: str,
+        subject_alternative_names: typing.Optional[typing.List[str]] = None,
+        validation_domains: typing.Optional[typing.Mapping[str, str]] = None,
+        validation_method: typing.Optional["ValidationMethod"] = None,
+    ) -> None:
         """Properties for your certificate.
 
         :param domain_name: Fully-qualified domain name to request a certificate for. May contain wildcards, such as ``*.domain.com``.
@@ -29,11 +57,14 @@ class CertificateProps():
         :stability: experimental
         """
         self._values = {
-            'domain_name': domain_name,
+            "domain_name": domain_name,
         }
-        if subject_alternative_names is not None: self._values["subject_alternative_names"] = subject_alternative_names
-        if validation_domains is not None: self._values["validation_domains"] = validation_domains
-        if validation_method is not None: self._values["validation_method"] = validation_method
+        if subject_alternative_names is not None:
+            self._values["subject_alternative_names"] = subject_alternative_names
+        if validation_domains is not None:
+            self._values["validation_domains"] = validation_domains
+        if validation_method is not None:
+            self._values["validation_method"] = validation_method
 
     @builtins.property
     def domain_name(self) -> str:
@@ -44,7 +75,7 @@ class CertificateProps():
         stability
         :stability: experimental
         """
-        return self._values.get('domain_name')
+        return self._values.get("domain_name")
 
     @builtins.property
     def subject_alternative_names(self) -> typing.Optional[typing.List[str]]:
@@ -58,7 +89,7 @@ class CertificateProps():
         stability
         :stability: experimental
         """
-        return self._values.get('subject_alternative_names')
+        return self._values.get("subject_alternative_names")
 
     @builtins.property
     def validation_domains(self) -> typing.Optional[typing.Mapping[str, str]]:
@@ -72,7 +103,7 @@ class CertificateProps():
         stability
         :stability: experimental
         """
-        return self._values.get('validation_domains')
+        return self._values.get("validation_domains")
 
     @builtins.property
     def validation_method(self) -> typing.Optional["ValidationMethod"]:
@@ -84,7 +115,7 @@ class CertificateProps():
         stability
         :stability: experimental
         """
-        return self._values.get('validation_method')
+        return self._values.get("validation_method")
 
     def __eq__(self, rhs) -> bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -93,11 +124,17 @@ class CertificateProps():
         return not (rhs == self)
 
     def __repr__(self) -> str:
-        return 'CertificateProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+        return "CertificateProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
 
 
 @jsii.implements(_IInspectable_051e6ed8)
-class CfnCertificate(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.aws_certificatemanager.CfnCertificate"):
+class CfnCertificate(
+    _CfnResource_7760e8e4,
+    metaclass=jsii.JSIIMeta,
+    jsii_type="monocdk-experiment.aws_certificatemanager.CfnCertificate",
+):
     """A CloudFormation ``AWS::CertificateManager::Certificate``.
 
     see
@@ -105,7 +142,29 @@ class CfnCertificate(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="
     cloudformationResource:
     :cloudformationResource:: AWS::CertificateManager::Certificate
     """
-    def __init__(self, scope: _Construct_f50a3f53, id: str, *, domain_name: str, certificate_authority_arn: typing.Optional[str]=None, certificate_transparency_logging_preference: typing.Optional[str]=None, domain_validation_options: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["DomainValidationOptionProperty", _IResolvable_9ceae33e]]]]=None, subject_alternative_names: typing.Optional[typing.List[str]]=None, tags: typing.Optional[typing.List[_CfnTag_b4661f1a]]=None, validation_method: typing.Optional[str]=None) -> None:
+
+    def __init__(
+        self,
+        scope: _Construct_f50a3f53,
+        id: str,
+        *,
+        domain_name: str,
+        certificate_authority_arn: typing.Optional[str] = None,
+        certificate_transparency_logging_preference: typing.Optional[str] = None,
+        domain_validation_options: typing.Optional[
+            typing.Union[
+                _IResolvable_9ceae33e,
+                typing.List[
+                    typing.Union[
+                        "DomainValidationOptionProperty", _IResolvable_9ceae33e
+                    ]
+                ],
+            ]
+        ] = None,
+        subject_alternative_names: typing.Optional[typing.List[str]] = None,
+        tags: typing.Optional[typing.List[_CfnTag_b4661f1a]] = None,
+        validation_method: typing.Optional[str] = None,
+    ) -> None:
         """Create a new ``AWS::CertificateManager::Certificate``.
 
         :param scope: - scope in which this resource is defined.
@@ -118,13 +177,28 @@ class CfnCertificate(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="
         :param tags: ``AWS::CertificateManager::Certificate.Tags``.
         :param validation_method: ``AWS::CertificateManager::Certificate.ValidationMethod``.
         """
-        props = CfnCertificateProps(domain_name=domain_name, certificate_authority_arn=certificate_authority_arn, certificate_transparency_logging_preference=certificate_transparency_logging_preference, domain_validation_options=domain_validation_options, subject_alternative_names=subject_alternative_names, tags=tags, validation_method=validation_method)
+        props = CfnCertificateProps(
+            domain_name=domain_name,
+            certificate_authority_arn=certificate_authority_arn,
+            certificate_transparency_logging_preference=certificate_transparency_logging_preference,
+            domain_validation_options=domain_validation_options,
+            subject_alternative_names=subject_alternative_names,
+            tags=tags,
+            validation_method=validation_method,
+        )
 
         jsii.create(CfnCertificate, self, [scope, id, props])
 
     @jsii.member(jsii_name="fromCloudFormation")
     @builtins.classmethod
-    def from_cloud_formation(cls, scope: _Construct_f50a3f53, id: str, resource_attributes: typing.Any, *, finder: _ICfnFinder_3b168f30) -> "CfnCertificate":
+    def from_cloud_formation(
+        cls,
+        scope: _Construct_f50a3f53,
+        id: str,
+        resource_attributes: typing.Any,
+        *,
+        finder: _ICfnFinder_3b168f30,
+    ) -> "CfnCertificate":
         """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
 
         Used in the @aws-cdk/cloudformation-include module.
@@ -139,7 +213,9 @@ class CfnCertificate(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="
         """
         options = _FromCloudFormationOptions_5f49f6f1(finder=finder)
 
-        return jsii.sinvoke(cls, "fromCloudFormation", [scope, id, resource_attributes, options])
+        return jsii.sinvoke(
+            cls, "fromCloudFormation", [scope, id, resource_attributes, options]
+        )
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
@@ -153,7 +229,9 @@ class CfnCertificate(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="
         return jsii.invoke(self, "inspect", [inspector])
 
     @jsii.member(jsii_name="renderProperties")
-    def _render_properties(self, props: typing.Mapping[str, typing.Any]) -> typing.Mapping[str, typing.Any]:
+    def _render_properties(
+        self, props: typing.Mapping[str, typing.Any]
+    ) -> typing.Mapping[str, typing.Any]:
         """
         :param props: -
         """
@@ -219,12 +297,23 @@ class CfnCertificate(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="
         return jsii.get(self, "certificateTransparencyLoggingPreference")
 
     @certificate_transparency_logging_preference.setter
-    def certificate_transparency_logging_preference(self, value: typing.Optional[str]) -> None:
+    def certificate_transparency_logging_preference(
+        self, value: typing.Optional[str]
+    ) -> None:
         jsii.set(self, "certificateTransparencyLoggingPreference", value)
 
     @builtins.property
     @jsii.member(jsii_name="domainValidationOptions")
-    def domain_validation_options(self) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["DomainValidationOptionProperty", _IResolvable_9ceae33e]]]]:
+    def domain_validation_options(
+        self,
+    ) -> typing.Optional[
+        typing.Union[
+            _IResolvable_9ceae33e,
+            typing.List[
+                typing.Union["DomainValidationOptionProperty", _IResolvable_9ceae33e]
+            ],
+        ]
+    ]:
         """``AWS::CertificateManager::Certificate.DomainValidationOptions``.
 
         see
@@ -233,7 +322,19 @@ class CfnCertificate(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="
         return jsii.get(self, "domainValidationOptions")
 
     @domain_validation_options.setter
-    def domain_validation_options(self, value: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["DomainValidationOptionProperty", _IResolvable_9ceae33e]]]]) -> None:
+    def domain_validation_options(
+        self,
+        value: typing.Optional[
+            typing.Union[
+                _IResolvable_9ceae33e,
+                typing.List[
+                    typing.Union[
+                        "DomainValidationOptionProperty", _IResolvable_9ceae33e
+                    ]
+                ],
+            ]
+        ],
+    ) -> None:
         jsii.set(self, "domainValidationOptions", value)
 
     @builtins.property
@@ -247,7 +348,9 @@ class CfnCertificate(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="
         return jsii.get(self, "subjectAlternativeNames")
 
     @subject_alternative_names.setter
-    def subject_alternative_names(self, value: typing.Optional[typing.List[str]]) -> None:
+    def subject_alternative_names(
+        self, value: typing.Optional[typing.List[str]]
+    ) -> None:
         jsii.set(self, "subjectAlternativeNames", value)
 
     @builtins.property
@@ -264,9 +367,23 @@ class CfnCertificate(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="
     def validation_method(self, value: typing.Optional[str]) -> None:
         jsii.set(self, "validationMethod", value)
 
-    @jsii.data_type(jsii_type="monocdk-experiment.aws_certificatemanager.CfnCertificate.DomainValidationOptionProperty", jsii_struct_bases=[], name_mapping={'domain_name': 'domainName', 'hosted_zone_id': 'hostedZoneId', 'validation_domain': 'validationDomain'})
-    class DomainValidationOptionProperty():
-        def __init__(self, *, domain_name: str, hosted_zone_id: typing.Optional[str]=None, validation_domain: typing.Optional[str]=None) -> None:
+    @jsii.data_type(
+        jsii_type="monocdk-experiment.aws_certificatemanager.CfnCertificate.DomainValidationOptionProperty",
+        jsii_struct_bases=[],
+        name_mapping={
+            "domain_name": "domainName",
+            "hosted_zone_id": "hostedZoneId",
+            "validation_domain": "validationDomain",
+        },
+    )
+    class DomainValidationOptionProperty:
+        def __init__(
+            self,
+            *,
+            domain_name: str,
+            hosted_zone_id: typing.Optional[str] = None,
+            validation_domain: typing.Optional[str] = None,
+        ) -> None:
             """
             :param domain_name: ``CfnCertificate.DomainValidationOptionProperty.DomainName``.
             :param hosted_zone_id: ``CfnCertificate.DomainValidationOptionProperty.HostedZoneId``.
@@ -276,10 +393,12 @@ class CfnCertificate(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-certificatemanager-certificate-domainvalidationoption.html
             """
             self._values = {
-                'domain_name': domain_name,
+                "domain_name": domain_name,
             }
-            if hosted_zone_id is not None: self._values["hosted_zone_id"] = hosted_zone_id
-            if validation_domain is not None: self._values["validation_domain"] = validation_domain
+            if hosted_zone_id is not None:
+                self._values["hosted_zone_id"] = hosted_zone_id
+            if validation_domain is not None:
+                self._values["validation_domain"] = validation_domain
 
         @builtins.property
         def domain_name(self) -> str:
@@ -288,7 +407,7 @@ class CfnCertificate(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-certificatemanager-certificate-domainvalidationoption.html#cfn-certificatemanager-certificate-domainvalidationoptions-domainname
             """
-            return self._values.get('domain_name')
+            return self._values.get("domain_name")
 
         @builtins.property
         def hosted_zone_id(self) -> typing.Optional[str]:
@@ -297,7 +416,7 @@ class CfnCertificate(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-certificatemanager-certificate-domainvalidationoption.html#cfn-certificatemanager-certificate-domainvalidationoption-hostedzoneid
             """
-            return self._values.get('hosted_zone_id')
+            return self._values.get("hosted_zone_id")
 
         @builtins.property
         def validation_domain(self) -> typing.Optional[str]:
@@ -306,7 +425,7 @@ class CfnCertificate(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-certificatemanager-certificate-domainvalidationoption.html#cfn-certificatemanager-certificate-domainvalidationoption-validationdomain
             """
-            return self._values.get('validation_domain')
+            return self._values.get("validation_domain")
 
         def __eq__(self, rhs) -> bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -315,13 +434,46 @@ class CfnCertificate(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="
             return not (rhs == self)
 
         def __repr__(self) -> str:
-            return 'DomainValidationOptionProperty(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+            return "DomainValidationOptionProperty(%s)" % ", ".join(
+                k + "=" + repr(v) for k, v in self._values.items()
+            )
 
 
-
-@jsii.data_type(jsii_type="monocdk-experiment.aws_certificatemanager.CfnCertificateProps", jsii_struct_bases=[], name_mapping={'domain_name': 'domainName', 'certificate_authority_arn': 'certificateAuthorityArn', 'certificate_transparency_logging_preference': 'certificateTransparencyLoggingPreference', 'domain_validation_options': 'domainValidationOptions', 'subject_alternative_names': 'subjectAlternativeNames', 'tags': 'tags', 'validation_method': 'validationMethod'})
-class CfnCertificateProps():
-    def __init__(self, *, domain_name: str, certificate_authority_arn: typing.Optional[str]=None, certificate_transparency_logging_preference: typing.Optional[str]=None, domain_validation_options: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnCertificate.DomainValidationOptionProperty", _IResolvable_9ceae33e]]]]=None, subject_alternative_names: typing.Optional[typing.List[str]]=None, tags: typing.Optional[typing.List[_CfnTag_b4661f1a]]=None, validation_method: typing.Optional[str]=None) -> None:
+@jsii.data_type(
+    jsii_type="monocdk-experiment.aws_certificatemanager.CfnCertificateProps",
+    jsii_struct_bases=[],
+    name_mapping={
+        "domain_name": "domainName",
+        "certificate_authority_arn": "certificateAuthorityArn",
+        "certificate_transparency_logging_preference": "certificateTransparencyLoggingPreference",
+        "domain_validation_options": "domainValidationOptions",
+        "subject_alternative_names": "subjectAlternativeNames",
+        "tags": "tags",
+        "validation_method": "validationMethod",
+    },
+)
+class CfnCertificateProps:
+    def __init__(
+        self,
+        *,
+        domain_name: str,
+        certificate_authority_arn: typing.Optional[str] = None,
+        certificate_transparency_logging_preference: typing.Optional[str] = None,
+        domain_validation_options: typing.Optional[
+            typing.Union[
+                _IResolvable_9ceae33e,
+                typing.List[
+                    typing.Union[
+                        "CfnCertificate.DomainValidationOptionProperty",
+                        _IResolvable_9ceae33e,
+                    ]
+                ],
+            ]
+        ] = None,
+        subject_alternative_names: typing.Optional[typing.List[str]] = None,
+        tags: typing.Optional[typing.List[_CfnTag_b4661f1a]] = None,
+        validation_method: typing.Optional[str] = None,
+    ) -> None:
         """Properties for defining a ``AWS::CertificateManager::Certificate``.
 
         :param domain_name: ``AWS::CertificateManager::Certificate.DomainName``.
@@ -336,14 +488,22 @@ class CfnCertificateProps():
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-certificatemanager-certificate.html
         """
         self._values = {
-            'domain_name': domain_name,
+            "domain_name": domain_name,
         }
-        if certificate_authority_arn is not None: self._values["certificate_authority_arn"] = certificate_authority_arn
-        if certificate_transparency_logging_preference is not None: self._values["certificate_transparency_logging_preference"] = certificate_transparency_logging_preference
-        if domain_validation_options is not None: self._values["domain_validation_options"] = domain_validation_options
-        if subject_alternative_names is not None: self._values["subject_alternative_names"] = subject_alternative_names
-        if tags is not None: self._values["tags"] = tags
-        if validation_method is not None: self._values["validation_method"] = validation_method
+        if certificate_authority_arn is not None:
+            self._values["certificate_authority_arn"] = certificate_authority_arn
+        if certificate_transparency_logging_preference is not None:
+            self._values[
+                "certificate_transparency_logging_preference"
+            ] = certificate_transparency_logging_preference
+        if domain_validation_options is not None:
+            self._values["domain_validation_options"] = domain_validation_options
+        if subject_alternative_names is not None:
+            self._values["subject_alternative_names"] = subject_alternative_names
+        if tags is not None:
+            self._values["tags"] = tags
+        if validation_method is not None:
+            self._values["validation_method"] = validation_method
 
     @builtins.property
     def domain_name(self) -> str:
@@ -352,7 +512,7 @@ class CfnCertificateProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-certificatemanager-certificate.html#cfn-certificatemanager-certificate-domainname
         """
-        return self._values.get('domain_name')
+        return self._values.get("domain_name")
 
     @builtins.property
     def certificate_authority_arn(self) -> typing.Optional[str]:
@@ -361,7 +521,7 @@ class CfnCertificateProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-certificatemanager-certificate.html#cfn-certificatemanager-certificate-certificateauthorityarn
         """
-        return self._values.get('certificate_authority_arn')
+        return self._values.get("certificate_authority_arn")
 
     @builtins.property
     def certificate_transparency_logging_preference(self) -> typing.Optional[str]:
@@ -370,16 +530,28 @@ class CfnCertificateProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-certificatemanager-certificate.html#cfn-certificatemanager-certificate-certificatetransparencyloggingpreference
         """
-        return self._values.get('certificate_transparency_logging_preference')
+        return self._values.get("certificate_transparency_logging_preference")
 
     @builtins.property
-    def domain_validation_options(self) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnCertificate.DomainValidationOptionProperty", _IResolvable_9ceae33e]]]]:
+    def domain_validation_options(
+        self,
+    ) -> typing.Optional[
+        typing.Union[
+            _IResolvable_9ceae33e,
+            typing.List[
+                typing.Union[
+                    "CfnCertificate.DomainValidationOptionProperty",
+                    _IResolvable_9ceae33e,
+                ]
+            ],
+        ]
+    ]:
         """``AWS::CertificateManager::Certificate.DomainValidationOptions``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-certificatemanager-certificate.html#cfn-certificatemanager-certificate-domainvalidationoptions
         """
-        return self._values.get('domain_validation_options')
+        return self._values.get("domain_validation_options")
 
     @builtins.property
     def subject_alternative_names(self) -> typing.Optional[typing.List[str]]:
@@ -388,7 +560,7 @@ class CfnCertificateProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-certificatemanager-certificate.html#cfn-certificatemanager-certificate-subjectalternativenames
         """
-        return self._values.get('subject_alternative_names')
+        return self._values.get("subject_alternative_names")
 
     @builtins.property
     def tags(self) -> typing.Optional[typing.List[_CfnTag_b4661f1a]]:
@@ -397,7 +569,7 @@ class CfnCertificateProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-certificatemanager-certificate.html#cfn-certificatemanager-certificate-tags
         """
-        return self._values.get('tags')
+        return self._values.get("tags")
 
     @builtins.property
     def validation_method(self) -> typing.Optional[str]:
@@ -406,7 +578,7 @@ class CfnCertificateProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-certificatemanager-certificate.html#cfn-certificatemanager-certificate-validationmethod
         """
-        return self._values.get('validation_method')
+        return self._values.get("validation_method")
 
     def __eq__(self, rhs) -> bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -415,12 +587,38 @@ class CfnCertificateProps():
         return not (rhs == self)
 
     def __repr__(self) -> str:
-        return 'CfnCertificateProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+        return "CfnCertificateProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
 
 
-@jsii.data_type(jsii_type="monocdk-experiment.aws_certificatemanager.DnsValidatedCertificateProps", jsii_struct_bases=[CertificateProps], name_mapping={'domain_name': 'domainName', 'subject_alternative_names': 'subjectAlternativeNames', 'validation_domains': 'validationDomains', 'validation_method': 'validationMethod', 'hosted_zone': 'hostedZone', 'custom_resource_role': 'customResourceRole', 'region': 'region', 'route53_endpoint': 'route53Endpoint'})
+@jsii.data_type(
+    jsii_type="monocdk-experiment.aws_certificatemanager.DnsValidatedCertificateProps",
+    jsii_struct_bases=[CertificateProps],
+    name_mapping={
+        "domain_name": "domainName",
+        "subject_alternative_names": "subjectAlternativeNames",
+        "validation_domains": "validationDomains",
+        "validation_method": "validationMethod",
+        "hosted_zone": "hostedZone",
+        "custom_resource_role": "customResourceRole",
+        "region": "region",
+        "route53_endpoint": "route53Endpoint",
+    },
+)
 class DnsValidatedCertificateProps(CertificateProps):
-    def __init__(self, *, domain_name: str, subject_alternative_names: typing.Optional[typing.List[str]]=None, validation_domains: typing.Optional[typing.Mapping[str, str]]=None, validation_method: typing.Optional["ValidationMethod"]=None, hosted_zone: _IHostedZone_59ffab76, custom_resource_role: typing.Optional[_IRole_e69bbae4]=None, region: typing.Optional[str]=None, route53_endpoint: typing.Optional[str]=None) -> None:
+    def __init__(
+        self,
+        *,
+        domain_name: str,
+        subject_alternative_names: typing.Optional[typing.List[str]] = None,
+        validation_domains: typing.Optional[typing.Mapping[str, str]] = None,
+        validation_method: typing.Optional["ValidationMethod"] = None,
+        hosted_zone: _IHostedZone_59ffab76,
+        custom_resource_role: typing.Optional[_IRole_e69bbae4] = None,
+        region: typing.Optional[str] = None,
+        route53_endpoint: typing.Optional[str] = None,
+    ) -> None:
         """Properties to create a DNS validated certificate managed by AWS Certificate Manager.
 
         :param domain_name: Fully-qualified domain name to request a certificate for. May contain wildcards, such as ``*.domain.com``.
@@ -436,15 +634,21 @@ class DnsValidatedCertificateProps(CertificateProps):
         :stability: experimental
         """
         self._values = {
-            'domain_name': domain_name,
-            'hosted_zone': hosted_zone,
+            "domain_name": domain_name,
+            "hosted_zone": hosted_zone,
         }
-        if subject_alternative_names is not None: self._values["subject_alternative_names"] = subject_alternative_names
-        if validation_domains is not None: self._values["validation_domains"] = validation_domains
-        if validation_method is not None: self._values["validation_method"] = validation_method
-        if custom_resource_role is not None: self._values["custom_resource_role"] = custom_resource_role
-        if region is not None: self._values["region"] = region
-        if route53_endpoint is not None: self._values["route53_endpoint"] = route53_endpoint
+        if subject_alternative_names is not None:
+            self._values["subject_alternative_names"] = subject_alternative_names
+        if validation_domains is not None:
+            self._values["validation_domains"] = validation_domains
+        if validation_method is not None:
+            self._values["validation_method"] = validation_method
+        if custom_resource_role is not None:
+            self._values["custom_resource_role"] = custom_resource_role
+        if region is not None:
+            self._values["region"] = region
+        if route53_endpoint is not None:
+            self._values["route53_endpoint"] = route53_endpoint
 
     @builtins.property
     def domain_name(self) -> str:
@@ -455,7 +659,7 @@ class DnsValidatedCertificateProps(CertificateProps):
         stability
         :stability: experimental
         """
-        return self._values.get('domain_name')
+        return self._values.get("domain_name")
 
     @builtins.property
     def subject_alternative_names(self) -> typing.Optional[typing.List[str]]:
@@ -469,7 +673,7 @@ class DnsValidatedCertificateProps(CertificateProps):
         stability
         :stability: experimental
         """
-        return self._values.get('subject_alternative_names')
+        return self._values.get("subject_alternative_names")
 
     @builtins.property
     def validation_domains(self) -> typing.Optional[typing.Mapping[str, str]]:
@@ -483,7 +687,7 @@ class DnsValidatedCertificateProps(CertificateProps):
         stability
         :stability: experimental
         """
-        return self._values.get('validation_domains')
+        return self._values.get("validation_domains")
 
     @builtins.property
     def validation_method(self) -> typing.Optional["ValidationMethod"]:
@@ -495,7 +699,7 @@ class DnsValidatedCertificateProps(CertificateProps):
         stability
         :stability: experimental
         """
-        return self._values.get('validation_method')
+        return self._values.get("validation_method")
 
     @builtins.property
     def hosted_zone(self) -> _IHostedZone_59ffab76:
@@ -507,7 +711,7 @@ class DnsValidatedCertificateProps(CertificateProps):
         stability
         :stability: experimental
         """
-        return self._values.get('hosted_zone')
+        return self._values.get("hosted_zone")
 
     @builtins.property
     def custom_resource_role(self) -> typing.Optional[_IRole_e69bbae4]:
@@ -519,7 +723,7 @@ class DnsValidatedCertificateProps(CertificateProps):
         stability
         :stability: experimental
         """
-        return self._values.get('custom_resource_role')
+        return self._values.get("custom_resource_role")
 
     @builtins.property
     def region(self) -> typing.Optional[str]:
@@ -535,7 +739,7 @@ class DnsValidatedCertificateProps(CertificateProps):
         stability
         :stability: experimental
         """
-        return self._values.get('region')
+        return self._values.get("region")
 
     @builtins.property
     def route53_endpoint(self) -> typing.Optional[str]:
@@ -551,7 +755,7 @@ class DnsValidatedCertificateProps(CertificateProps):
         stability
         :stability: experimental
         """
-        return self._values.get('route53_endpoint')
+        return self._values.get("route53_endpoint")
 
     def __eq__(self, rhs) -> bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -560,7 +764,9 @@ class DnsValidatedCertificateProps(CertificateProps):
         return not (rhs == self)
 
     def __repr__(self) -> str:
-        return 'DnsValidatedCertificateProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+        return "DnsValidatedCertificateProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
 
 
 @jsii.interface(jsii_type="monocdk-experiment.aws_certificatemanager.ICertificate")
@@ -570,6 +776,7 @@ class ICertificate(_IResource_72f7ee7e, jsii.compat.Protocol):
     stability
     :stability: experimental
     """
+
     @builtins.staticmethod
     def __jsii_proxy_class__():
         return _ICertificateProxy
@@ -593,7 +800,9 @@ class _ICertificateProxy(jsii.proxy_for(_IResource_72f7ee7e)):
     stability
     :stability: experimental
     """
+
     __jsii_type__ = "monocdk-experiment.aws_certificatemanager.ICertificate"
+
     @builtins.property
     @jsii.member(jsii_name="certificateArn")
     def certificate_arn(self) -> str:
@@ -614,6 +823,7 @@ class ValidationMethod(enum.Enum):
     stability
     :stability: experimental
     """
+
     EMAIL = "EMAIL"
     """Send email to a number of email addresses associated with the domain.
 
@@ -631,8 +841,13 @@ class ValidationMethod(enum.Enum):
     :stability: experimental
     """
 
+
 @jsii.implements(ICertificate)
-class Certificate(_Resource_884d0774, metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.aws_certificatemanager.Certificate"):
+class Certificate(
+    _Resource_884d0774,
+    metaclass=jsii.JSIIMeta,
+    jsii_type="monocdk-experiment.aws_certificatemanager.Certificate",
+):
     """A certificate managed by AWS Certificate Manager.
 
     IMPORTANT: if you are creating a certificate as part of your stack, the stack
@@ -652,7 +867,17 @@ class Certificate(_Resource_884d0774, metaclass=jsii.JSIIMeta, jsii_type="monocd
     stability
     :stability: experimental
     """
-    def __init__(self, scope: _Construct_f50a3f53, id: str, *, domain_name: str, subject_alternative_names: typing.Optional[typing.List[str]]=None, validation_domains: typing.Optional[typing.Mapping[str, str]]=None, validation_method: typing.Optional["ValidationMethod"]=None) -> None:
+
+    def __init__(
+        self,
+        scope: _Construct_f50a3f53,
+        id: str,
+        *,
+        domain_name: str,
+        subject_alternative_names: typing.Optional[typing.List[str]] = None,
+        validation_domains: typing.Optional[typing.Mapping[str, str]] = None,
+        validation_method: typing.Optional["ValidationMethod"] = None,
+    ) -> None:
         """
         :param scope: -
         :param id: -
@@ -664,13 +889,20 @@ class Certificate(_Resource_884d0774, metaclass=jsii.JSIIMeta, jsii_type="monocd
         stability
         :stability: experimental
         """
-        props = CertificateProps(domain_name=domain_name, subject_alternative_names=subject_alternative_names, validation_domains=validation_domains, validation_method=validation_method)
+        props = CertificateProps(
+            domain_name=domain_name,
+            subject_alternative_names=subject_alternative_names,
+            validation_domains=validation_domains,
+            validation_method=validation_method,
+        )
 
         jsii.create(Certificate, self, [scope, id, props])
 
     @jsii.member(jsii_name="fromCertificateArn")
     @builtins.classmethod
-    def from_certificate_arn(cls, scope: _Construct_f50a3f53, id: str, certificate_arn: str) -> "ICertificate":
+    def from_certificate_arn(
+        cls, scope: _Construct_f50a3f53, id: str, certificate_arn: str
+    ) -> "ICertificate":
         """Import a certificate.
 
         :param scope: -
@@ -694,7 +926,11 @@ class Certificate(_Resource_884d0774, metaclass=jsii.JSIIMeta, jsii_type="monocd
 
 
 @jsii.implements(ICertificate)
-class DnsValidatedCertificate(_Resource_884d0774, metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.aws_certificatemanager.DnsValidatedCertificate"):
+class DnsValidatedCertificate(
+    _Resource_884d0774,
+    metaclass=jsii.JSIIMeta,
+    jsii_type="monocdk-experiment.aws_certificatemanager.DnsValidatedCertificate",
+):
     """A certificate managed by AWS Certificate Manager.
 
     Will be automatically
@@ -705,7 +941,21 @@ class DnsValidatedCertificate(_Resource_884d0774, metaclass=jsii.JSIIMeta, jsii_
     resource:
     :resource:: AWS::CertificateManager::Certificate
     """
-    def __init__(self, scope: _Construct_f50a3f53, id: str, *, hosted_zone: _IHostedZone_59ffab76, custom_resource_role: typing.Optional[_IRole_e69bbae4]=None, region: typing.Optional[str]=None, route53_endpoint: typing.Optional[str]=None, domain_name: str, subject_alternative_names: typing.Optional[typing.List[str]]=None, validation_domains: typing.Optional[typing.Mapping[str, str]]=None, validation_method: typing.Optional["ValidationMethod"]=None) -> None:
+
+    def __init__(
+        self,
+        scope: _Construct_f50a3f53,
+        id: str,
+        *,
+        hosted_zone: _IHostedZone_59ffab76,
+        custom_resource_role: typing.Optional[_IRole_e69bbae4] = None,
+        region: typing.Optional[str] = None,
+        route53_endpoint: typing.Optional[str] = None,
+        domain_name: str,
+        subject_alternative_names: typing.Optional[typing.List[str]] = None,
+        validation_domains: typing.Optional[typing.Mapping[str, str]] = None,
+        validation_method: typing.Optional["ValidationMethod"] = None,
+    ) -> None:
         """
         :param scope: -
         :param id: -
@@ -721,7 +971,16 @@ class DnsValidatedCertificate(_Resource_884d0774, metaclass=jsii.JSIIMeta, jsii_
         stability
         :stability: experimental
         """
-        props = DnsValidatedCertificateProps(hosted_zone=hosted_zone, custom_resource_role=custom_resource_role, region=region, route53_endpoint=route53_endpoint, domain_name=domain_name, subject_alternative_names=subject_alternative_names, validation_domains=validation_domains, validation_method=validation_method)
+        props = DnsValidatedCertificateProps(
+            hosted_zone=hosted_zone,
+            custom_resource_role=custom_resource_role,
+            region=region,
+            route53_endpoint=route53_endpoint,
+            domain_name=domain_name,
+            subject_alternative_names=subject_alternative_names,
+            validation_domains=validation_domains,
+            validation_method=validation_method,
+        )
 
         jsii.create(DnsValidatedCertificate, self, [scope, id, props])
 
