@@ -10,11 +10,25 @@ import publication
 
 from .._jsii import *
 
-from .. import (CfnResource as _CfnResource_7760e8e4, Construct as _Construct_f50a3f53, FromCloudFormationOptions as _FromCloudFormationOptions_5f49f6f1, TreeInspector as _TreeInspector_154f5999, TagManager as _TagManager_2508893f, IResolvable as _IResolvable_9ceae33e, IInspectable as _IInspectable_051e6ed8, CfnTag as _CfnTag_b4661f1a)
+from .. import (
+    CfnResource as _CfnResource_7760e8e4,
+    Construct as _Construct_f50a3f53,
+    IResolvable as _IResolvable_9ceae33e,
+    CfnTag as _CfnTag_b4661f1a,
+    FromCloudFormationOptions as _FromCloudFormationOptions_5f49f6f1,
+    ICfnFinder as _ICfnFinder_3b168f30,
+    TreeInspector as _TreeInspector_154f5999,
+    TagManager as _TagManager_2508893f,
+    IInspectable as _IInspectable_051e6ed8,
+)
 
 
 @jsii.implements(_IInspectable_051e6ed8)
-class CfnCanary(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.aws_synthetics.CfnCanary"):
+class CfnCanary(
+    _CfnResource_7760e8e4,
+    metaclass=jsii.JSIIMeta,
+    jsii_type="monocdk-experiment.aws_synthetics.CfnCanary",
+):
     """A CloudFormation ``AWS::Synthetics::Canary``.
 
     see
@@ -22,7 +36,27 @@ class CfnCanary(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monoc
     cloudformationResource:
     :cloudformationResource:: AWS::Synthetics::Canary
     """
-    def __init__(self, scope: _Construct_f50a3f53, id: str, *, artifact_s3_location: str, code: typing.Union["CodeProperty", _IResolvable_9ceae33e], execution_role_arn: str, name: str, run_config: typing.Union["RunConfigProperty", _IResolvable_9ceae33e], runtime_version: str, schedule: typing.Union["ScheduleProperty", _IResolvable_9ceae33e], start_canary_after_creation: typing.Union[bool, _IResolvable_9ceae33e], failure_retention_period: typing.Optional[jsii.Number]=None, success_retention_period: typing.Optional[jsii.Number]=None, tags: typing.Optional[typing.List[_CfnTag_b4661f1a]]=None, vpc_config: typing.Optional[typing.Union["VPCConfigProperty", _IResolvable_9ceae33e]]=None) -> None:
+
+    def __init__(
+        self,
+        scope: _Construct_f50a3f53,
+        id: str,
+        *,
+        artifact_s3_location: str,
+        code: typing.Union["CodeProperty", _IResolvable_9ceae33e],
+        execution_role_arn: str,
+        name: str,
+        run_config: typing.Union["RunConfigProperty", _IResolvable_9ceae33e],
+        runtime_version: str,
+        schedule: typing.Union["ScheduleProperty", _IResolvable_9ceae33e],
+        start_canary_after_creation: typing.Union[bool, _IResolvable_9ceae33e],
+        failure_retention_period: typing.Optional[jsii.Number] = None,
+        success_retention_period: typing.Optional[jsii.Number] = None,
+        tags: typing.Optional[typing.List[_CfnTag_b4661f1a]] = None,
+        vpc_config: typing.Optional[
+            typing.Union["VPCConfigProperty", _IResolvable_9ceae33e]
+        ] = None,
+    ) -> None:
         """Create a new ``AWS::Synthetics::Canary``.
 
         :param scope: - scope in which this resource is defined.
@@ -40,13 +74,33 @@ class CfnCanary(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monoc
         :param tags: ``AWS::Synthetics::Canary.Tags``.
         :param vpc_config: ``AWS::Synthetics::Canary.VPCConfig``.
         """
-        props = CfnCanaryProps(artifact_s3_location=artifact_s3_location, code=code, execution_role_arn=execution_role_arn, name=name, run_config=run_config, runtime_version=runtime_version, schedule=schedule, start_canary_after_creation=start_canary_after_creation, failure_retention_period=failure_retention_period, success_retention_period=success_retention_period, tags=tags, vpc_config=vpc_config)
+        props = CfnCanaryProps(
+            artifact_s3_location=artifact_s3_location,
+            code=code,
+            execution_role_arn=execution_role_arn,
+            name=name,
+            run_config=run_config,
+            runtime_version=runtime_version,
+            schedule=schedule,
+            start_canary_after_creation=start_canary_after_creation,
+            failure_retention_period=failure_retention_period,
+            success_retention_period=success_retention_period,
+            tags=tags,
+            vpc_config=vpc_config,
+        )
 
         jsii.create(CfnCanary, self, [scope, id, props])
 
     @jsii.member(jsii_name="fromCloudFormation")
     @builtins.classmethod
-    def from_cloud_formation(cls, scope: _Construct_f50a3f53, id: str, resource_attributes: typing.Any, *, finder: _ICfnFinder_3b168f30) -> "CfnCanary":
+    def from_cloud_formation(
+        cls,
+        scope: _Construct_f50a3f53,
+        id: str,
+        resource_attributes: typing.Any,
+        *,
+        finder: _ICfnFinder_3b168f30,
+    ) -> "CfnCanary":
         """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
 
         Used in the @aws-cdk/cloudformation-include module.
@@ -61,7 +115,9 @@ class CfnCanary(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monoc
         """
         options = _FromCloudFormationOptions_5f49f6f1(finder=finder)
 
-        return jsii.sinvoke(cls, "fromCloudFormation", [scope, id, resource_attributes, options])
+        return jsii.sinvoke(
+            cls, "fromCloudFormation", [scope, id, resource_attributes, options]
+        )
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
@@ -75,7 +131,9 @@ class CfnCanary(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monoc
         return jsii.invoke(self, "inspect", [inspector])
 
     @jsii.member(jsii_name="renderProperties")
-    def _render_properties(self, props: typing.Mapping[str, typing.Any]) -> typing.Mapping[str, typing.Any]:
+    def _render_properties(
+        self, props: typing.Mapping[str, typing.Any]
+    ) -> typing.Mapping[str, typing.Any]:
         """
         :param props: -
         """
@@ -187,7 +245,9 @@ class CfnCanary(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monoc
         return jsii.get(self, "runConfig")
 
     @run_config.setter
-    def run_config(self, value: typing.Union["RunConfigProperty", _IResolvable_9ceae33e]) -> None:
+    def run_config(
+        self, value: typing.Union["RunConfigProperty", _IResolvable_9ceae33e]
+    ) -> None:
         jsii.set(self, "runConfig", value)
 
     @builtins.property
@@ -215,7 +275,9 @@ class CfnCanary(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monoc
         return jsii.get(self, "schedule")
 
     @schedule.setter
-    def schedule(self, value: typing.Union["ScheduleProperty", _IResolvable_9ceae33e]) -> None:
+    def schedule(
+        self, value: typing.Union["ScheduleProperty", _IResolvable_9ceae33e]
+    ) -> None:
         jsii.set(self, "schedule", value)
 
     @builtins.property
@@ -229,7 +291,9 @@ class CfnCanary(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monoc
         return jsii.get(self, "startCanaryAfterCreation")
 
     @start_canary_after_creation.setter
-    def start_canary_after_creation(self, value: typing.Union[bool, _IResolvable_9ceae33e]) -> None:
+    def start_canary_after_creation(
+        self, value: typing.Union[bool, _IResolvable_9ceae33e]
+    ) -> None:
         jsii.set(self, "startCanaryAfterCreation", value)
 
     @builtins.property
@@ -262,7 +326,9 @@ class CfnCanary(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monoc
 
     @builtins.property
     @jsii.member(jsii_name="vpcConfig")
-    def vpc_config(self) -> typing.Optional[typing.Union["VPCConfigProperty", _IResolvable_9ceae33e]]:
+    def vpc_config(
+        self,
+    ) -> typing.Optional[typing.Union["VPCConfigProperty", _IResolvable_9ceae33e]]:
         """``AWS::Synthetics::Canary.VPCConfig``.
 
         see
@@ -271,12 +337,35 @@ class CfnCanary(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monoc
         return jsii.get(self, "vpcConfig")
 
     @vpc_config.setter
-    def vpc_config(self, value: typing.Optional[typing.Union["VPCConfigProperty", _IResolvable_9ceae33e]]) -> None:
+    def vpc_config(
+        self,
+        value: typing.Optional[
+            typing.Union["VPCConfigProperty", _IResolvable_9ceae33e]
+        ],
+    ) -> None:
         jsii.set(self, "vpcConfig", value)
 
-    @jsii.data_type(jsii_type="monocdk-experiment.aws_synthetics.CfnCanary.CodeProperty", jsii_struct_bases=[], name_mapping={'handler': 'handler', 's3_bucket': 's3Bucket', 's3_key': 's3Key', 's3_object_version': 's3ObjectVersion', 'script': 'script'})
-    class CodeProperty():
-        def __init__(self, *, handler: typing.Optional[str]=None, s3_bucket: typing.Optional[str]=None, s3_key: typing.Optional[str]=None, s3_object_version: typing.Optional[str]=None, script: typing.Optional[str]=None) -> None:
+    @jsii.data_type(
+        jsii_type="monocdk-experiment.aws_synthetics.CfnCanary.CodeProperty",
+        jsii_struct_bases=[],
+        name_mapping={
+            "handler": "handler",
+            "s3_bucket": "s3Bucket",
+            "s3_key": "s3Key",
+            "s3_object_version": "s3ObjectVersion",
+            "script": "script",
+        },
+    )
+    class CodeProperty:
+        def __init__(
+            self,
+            *,
+            handler: typing.Optional[str] = None,
+            s3_bucket: typing.Optional[str] = None,
+            s3_key: typing.Optional[str] = None,
+            s3_object_version: typing.Optional[str] = None,
+            script: typing.Optional[str] = None,
+        ) -> None:
             """
             :param handler: ``CfnCanary.CodeProperty.Handler``.
             :param s3_bucket: ``CfnCanary.CodeProperty.S3Bucket``.
@@ -287,13 +376,17 @@ class CfnCanary(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monoc
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-synthetics-canary-code.html
             """
-            self._values = {
-            }
-            if handler is not None: self._values["handler"] = handler
-            if s3_bucket is not None: self._values["s3_bucket"] = s3_bucket
-            if s3_key is not None: self._values["s3_key"] = s3_key
-            if s3_object_version is not None: self._values["s3_object_version"] = s3_object_version
-            if script is not None: self._values["script"] = script
+            self._values = {}
+            if handler is not None:
+                self._values["handler"] = handler
+            if s3_bucket is not None:
+                self._values["s3_bucket"] = s3_bucket
+            if s3_key is not None:
+                self._values["s3_key"] = s3_key
+            if s3_object_version is not None:
+                self._values["s3_object_version"] = s3_object_version
+            if script is not None:
+                self._values["script"] = script
 
         @builtins.property
         def handler(self) -> typing.Optional[str]:
@@ -302,7 +395,7 @@ class CfnCanary(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monoc
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-synthetics-canary-code.html#cfn-synthetics-canary-code-handler
             """
-            return self._values.get('handler')
+            return self._values.get("handler")
 
         @builtins.property
         def s3_bucket(self) -> typing.Optional[str]:
@@ -311,7 +404,7 @@ class CfnCanary(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monoc
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-synthetics-canary-code.html#cfn-synthetics-canary-code-s3bucket
             """
-            return self._values.get('s3_bucket')
+            return self._values.get("s3_bucket")
 
         @builtins.property
         def s3_key(self) -> typing.Optional[str]:
@@ -320,7 +413,7 @@ class CfnCanary(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monoc
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-synthetics-canary-code.html#cfn-synthetics-canary-code-s3key
             """
-            return self._values.get('s3_key')
+            return self._values.get("s3_key")
 
         @builtins.property
         def s3_object_version(self) -> typing.Optional[str]:
@@ -329,7 +422,7 @@ class CfnCanary(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monoc
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-synthetics-canary-code.html#cfn-synthetics-canary-code-s3objectversion
             """
-            return self._values.get('s3_object_version')
+            return self._values.get("s3_object_version")
 
         @builtins.property
         def script(self) -> typing.Optional[str]:
@@ -338,7 +431,7 @@ class CfnCanary(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monoc
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-synthetics-canary-code.html#cfn-synthetics-canary-code-script
             """
-            return self._values.get('script')
+            return self._values.get("script")
 
         def __eq__(self, rhs) -> bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -347,11 +440,16 @@ class CfnCanary(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monoc
             return not (rhs == self)
 
         def __repr__(self) -> str:
-            return 'CodeProperty(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+            return "CodeProperty(%s)" % ", ".join(
+                k + "=" + repr(v) for k, v in self._values.items()
+            )
 
-
-    @jsii.data_type(jsii_type="monocdk-experiment.aws_synthetics.CfnCanary.RunConfigProperty", jsii_struct_bases=[], name_mapping={'timeout_in_seconds': 'timeoutInSeconds'})
-    class RunConfigProperty():
+    @jsii.data_type(
+        jsii_type="monocdk-experiment.aws_synthetics.CfnCanary.RunConfigProperty",
+        jsii_struct_bases=[],
+        name_mapping={"timeout_in_seconds": "timeoutInSeconds"},
+    )
+    class RunConfigProperty:
         def __init__(self, *, timeout_in_seconds: jsii.Number) -> None:
             """
             :param timeout_in_seconds: ``CfnCanary.RunConfigProperty.TimeoutInSeconds``.
@@ -360,7 +458,7 @@ class CfnCanary(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monoc
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-synthetics-canary-runconfig.html
             """
             self._values = {
-                'timeout_in_seconds': timeout_in_seconds,
+                "timeout_in_seconds": timeout_in_seconds,
             }
 
         @builtins.property
@@ -370,7 +468,7 @@ class CfnCanary(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monoc
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-synthetics-canary-runconfig.html#cfn-synthetics-canary-runconfig-timeoutinseconds
             """
-            return self._values.get('timeout_in_seconds')
+            return self._values.get("timeout_in_seconds")
 
         def __eq__(self, rhs) -> bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -379,11 +477,19 @@ class CfnCanary(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monoc
             return not (rhs == self)
 
         def __repr__(self) -> str:
-            return 'RunConfigProperty(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+            return "RunConfigProperty(%s)" % ", ".join(
+                k + "=" + repr(v) for k, v in self._values.items()
+            )
 
-
-    @jsii.data_type(jsii_type="monocdk-experiment.aws_synthetics.CfnCanary.ScheduleProperty", jsii_struct_bases=[], name_mapping={'duration_in_seconds': 'durationInSeconds', 'expression': 'expression'})
-    class ScheduleProperty():
+    @jsii.data_type(
+        jsii_type="monocdk-experiment.aws_synthetics.CfnCanary.ScheduleProperty",
+        jsii_struct_bases=[],
+        name_mapping={
+            "duration_in_seconds": "durationInSeconds",
+            "expression": "expression",
+        },
+    )
+    class ScheduleProperty:
         def __init__(self, *, duration_in_seconds: str, expression: str) -> None:
             """
             :param duration_in_seconds: ``CfnCanary.ScheduleProperty.DurationInSeconds``.
@@ -393,8 +499,8 @@ class CfnCanary(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monoc
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-synthetics-canary-schedule.html
             """
             self._values = {
-                'duration_in_seconds': duration_in_seconds,
-                'expression': expression,
+                "duration_in_seconds": duration_in_seconds,
+                "expression": expression,
             }
 
         @builtins.property
@@ -404,7 +510,7 @@ class CfnCanary(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monoc
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-synthetics-canary-schedule.html#cfn-synthetics-canary-schedule-durationinseconds
             """
-            return self._values.get('duration_in_seconds')
+            return self._values.get("duration_in_seconds")
 
         @builtins.property
         def expression(self) -> str:
@@ -413,7 +519,7 @@ class CfnCanary(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monoc
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-synthetics-canary-schedule.html#cfn-synthetics-canary-schedule-expression
             """
-            return self._values.get('expression')
+            return self._values.get("expression")
 
         def __eq__(self, rhs) -> bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -422,12 +528,27 @@ class CfnCanary(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monoc
             return not (rhs == self)
 
         def __repr__(self) -> str:
-            return 'ScheduleProperty(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+            return "ScheduleProperty(%s)" % ", ".join(
+                k + "=" + repr(v) for k, v in self._values.items()
+            )
 
-
-    @jsii.data_type(jsii_type="monocdk-experiment.aws_synthetics.CfnCanary.VPCConfigProperty", jsii_struct_bases=[], name_mapping={'security_group_ids': 'securityGroupIds', 'subnet_ids': 'subnetIds', 'vpc_id': 'vpcId'})
-    class VPCConfigProperty():
-        def __init__(self, *, security_group_ids: typing.List[str], subnet_ids: typing.List[str], vpc_id: typing.Optional[str]=None) -> None:
+    @jsii.data_type(
+        jsii_type="monocdk-experiment.aws_synthetics.CfnCanary.VPCConfigProperty",
+        jsii_struct_bases=[],
+        name_mapping={
+            "security_group_ids": "securityGroupIds",
+            "subnet_ids": "subnetIds",
+            "vpc_id": "vpcId",
+        },
+    )
+    class VPCConfigProperty:
+        def __init__(
+            self,
+            *,
+            security_group_ids: typing.List[str],
+            subnet_ids: typing.List[str],
+            vpc_id: typing.Optional[str] = None,
+        ) -> None:
             """
             :param security_group_ids: ``CfnCanary.VPCConfigProperty.SecurityGroupIds``.
             :param subnet_ids: ``CfnCanary.VPCConfigProperty.SubnetIds``.
@@ -437,10 +558,11 @@ class CfnCanary(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monoc
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-synthetics-canary-vpcconfig.html
             """
             self._values = {
-                'security_group_ids': security_group_ids,
-                'subnet_ids': subnet_ids,
+                "security_group_ids": security_group_ids,
+                "subnet_ids": subnet_ids,
             }
-            if vpc_id is not None: self._values["vpc_id"] = vpc_id
+            if vpc_id is not None:
+                self._values["vpc_id"] = vpc_id
 
         @builtins.property
         def security_group_ids(self) -> typing.List[str]:
@@ -449,7 +571,7 @@ class CfnCanary(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monoc
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-synthetics-canary-vpcconfig.html#cfn-synthetics-canary-vpcconfig-securitygroupids
             """
-            return self._values.get('security_group_ids')
+            return self._values.get("security_group_ids")
 
         @builtins.property
         def subnet_ids(self) -> typing.List[str]:
@@ -458,7 +580,7 @@ class CfnCanary(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monoc
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-synthetics-canary-vpcconfig.html#cfn-synthetics-canary-vpcconfig-subnetids
             """
-            return self._values.get('subnet_ids')
+            return self._values.get("subnet_ids")
 
         @builtins.property
         def vpc_id(self) -> typing.Optional[str]:
@@ -467,7 +589,7 @@ class CfnCanary(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monoc
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-synthetics-canary-vpcconfig.html#cfn-synthetics-canary-vpcconfig-vpcid
             """
-            return self._values.get('vpc_id')
+            return self._values.get("vpc_id")
 
         def __eq__(self, rhs) -> bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -476,13 +598,48 @@ class CfnCanary(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monoc
             return not (rhs == self)
 
         def __repr__(self) -> str:
-            return 'VPCConfigProperty(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+            return "VPCConfigProperty(%s)" % ", ".join(
+                k + "=" + repr(v) for k, v in self._values.items()
+            )
 
 
-
-@jsii.data_type(jsii_type="monocdk-experiment.aws_synthetics.CfnCanaryProps", jsii_struct_bases=[], name_mapping={'artifact_s3_location': 'artifactS3Location', 'code': 'code', 'execution_role_arn': 'executionRoleArn', 'name': 'name', 'run_config': 'runConfig', 'runtime_version': 'runtimeVersion', 'schedule': 'schedule', 'start_canary_after_creation': 'startCanaryAfterCreation', 'failure_retention_period': 'failureRetentionPeriod', 'success_retention_period': 'successRetentionPeriod', 'tags': 'tags', 'vpc_config': 'vpcConfig'})
-class CfnCanaryProps():
-    def __init__(self, *, artifact_s3_location: str, code: typing.Union["CfnCanary.CodeProperty", _IResolvable_9ceae33e], execution_role_arn: str, name: str, run_config: typing.Union["CfnCanary.RunConfigProperty", _IResolvable_9ceae33e], runtime_version: str, schedule: typing.Union["CfnCanary.ScheduleProperty", _IResolvable_9ceae33e], start_canary_after_creation: typing.Union[bool, _IResolvable_9ceae33e], failure_retention_period: typing.Optional[jsii.Number]=None, success_retention_period: typing.Optional[jsii.Number]=None, tags: typing.Optional[typing.List[_CfnTag_b4661f1a]]=None, vpc_config: typing.Optional[typing.Union["CfnCanary.VPCConfigProperty", _IResolvable_9ceae33e]]=None) -> None:
+@jsii.data_type(
+    jsii_type="monocdk-experiment.aws_synthetics.CfnCanaryProps",
+    jsii_struct_bases=[],
+    name_mapping={
+        "artifact_s3_location": "artifactS3Location",
+        "code": "code",
+        "execution_role_arn": "executionRoleArn",
+        "name": "name",
+        "run_config": "runConfig",
+        "runtime_version": "runtimeVersion",
+        "schedule": "schedule",
+        "start_canary_after_creation": "startCanaryAfterCreation",
+        "failure_retention_period": "failureRetentionPeriod",
+        "success_retention_period": "successRetentionPeriod",
+        "tags": "tags",
+        "vpc_config": "vpcConfig",
+    },
+)
+class CfnCanaryProps:
+    def __init__(
+        self,
+        *,
+        artifact_s3_location: str,
+        code: typing.Union["CfnCanary.CodeProperty", _IResolvable_9ceae33e],
+        execution_role_arn: str,
+        name: str,
+        run_config: typing.Union["CfnCanary.RunConfigProperty", _IResolvable_9ceae33e],
+        runtime_version: str,
+        schedule: typing.Union["CfnCanary.ScheduleProperty", _IResolvable_9ceae33e],
+        start_canary_after_creation: typing.Union[bool, _IResolvable_9ceae33e],
+        failure_retention_period: typing.Optional[jsii.Number] = None,
+        success_retention_period: typing.Optional[jsii.Number] = None,
+        tags: typing.Optional[typing.List[_CfnTag_b4661f1a]] = None,
+        vpc_config: typing.Optional[
+            typing.Union["CfnCanary.VPCConfigProperty", _IResolvable_9ceae33e]
+        ] = None,
+    ) -> None:
         """Properties for defining a ``AWS::Synthetics::Canary``.
 
         :param artifact_s3_location: ``AWS::Synthetics::Canary.ArtifactS3Location``.
@@ -502,19 +659,23 @@ class CfnCanaryProps():
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-synthetics-canary.html
         """
         self._values = {
-            'artifact_s3_location': artifact_s3_location,
-            'code': code,
-            'execution_role_arn': execution_role_arn,
-            'name': name,
-            'run_config': run_config,
-            'runtime_version': runtime_version,
-            'schedule': schedule,
-            'start_canary_after_creation': start_canary_after_creation,
+            "artifact_s3_location": artifact_s3_location,
+            "code": code,
+            "execution_role_arn": execution_role_arn,
+            "name": name,
+            "run_config": run_config,
+            "runtime_version": runtime_version,
+            "schedule": schedule,
+            "start_canary_after_creation": start_canary_after_creation,
         }
-        if failure_retention_period is not None: self._values["failure_retention_period"] = failure_retention_period
-        if success_retention_period is not None: self._values["success_retention_period"] = success_retention_period
-        if tags is not None: self._values["tags"] = tags
-        if vpc_config is not None: self._values["vpc_config"] = vpc_config
+        if failure_retention_period is not None:
+            self._values["failure_retention_period"] = failure_retention_period
+        if success_retention_period is not None:
+            self._values["success_retention_period"] = success_retention_period
+        if tags is not None:
+            self._values["tags"] = tags
+        if vpc_config is not None:
+            self._values["vpc_config"] = vpc_config
 
     @builtins.property
     def artifact_s3_location(self) -> str:
@@ -523,7 +684,7 @@ class CfnCanaryProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-synthetics-canary.html#cfn-synthetics-canary-artifacts3location
         """
-        return self._values.get('artifact_s3_location')
+        return self._values.get("artifact_s3_location")
 
     @builtins.property
     def code(self) -> typing.Union["CfnCanary.CodeProperty", _IResolvable_9ceae33e]:
@@ -532,7 +693,7 @@ class CfnCanaryProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-synthetics-canary.html#cfn-synthetics-canary-code
         """
-        return self._values.get('code')
+        return self._values.get("code")
 
     @builtins.property
     def execution_role_arn(self) -> str:
@@ -541,7 +702,7 @@ class CfnCanaryProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-synthetics-canary.html#cfn-synthetics-canary-executionrolearn
         """
-        return self._values.get('execution_role_arn')
+        return self._values.get("execution_role_arn")
 
     @builtins.property
     def name(self) -> str:
@@ -550,16 +711,18 @@ class CfnCanaryProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-synthetics-canary.html#cfn-synthetics-canary-name
         """
-        return self._values.get('name')
+        return self._values.get("name")
 
     @builtins.property
-    def run_config(self) -> typing.Union["CfnCanary.RunConfigProperty", _IResolvable_9ceae33e]:
+    def run_config(
+        self,
+    ) -> typing.Union["CfnCanary.RunConfigProperty", _IResolvable_9ceae33e]:
         """``AWS::Synthetics::Canary.RunConfig``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-synthetics-canary.html#cfn-synthetics-canary-runconfig
         """
-        return self._values.get('run_config')
+        return self._values.get("run_config")
 
     @builtins.property
     def runtime_version(self) -> str:
@@ -568,16 +731,18 @@ class CfnCanaryProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-synthetics-canary.html#cfn-synthetics-canary-runtimeversion
         """
-        return self._values.get('runtime_version')
+        return self._values.get("runtime_version")
 
     @builtins.property
-    def schedule(self) -> typing.Union["CfnCanary.ScheduleProperty", _IResolvable_9ceae33e]:
+    def schedule(
+        self,
+    ) -> typing.Union["CfnCanary.ScheduleProperty", _IResolvable_9ceae33e]:
         """``AWS::Synthetics::Canary.Schedule``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-synthetics-canary.html#cfn-synthetics-canary-schedule
         """
-        return self._values.get('schedule')
+        return self._values.get("schedule")
 
     @builtins.property
     def start_canary_after_creation(self) -> typing.Union[bool, _IResolvable_9ceae33e]:
@@ -586,7 +751,7 @@ class CfnCanaryProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-synthetics-canary.html#cfn-synthetics-canary-startcanaryaftercreation
         """
-        return self._values.get('start_canary_after_creation')
+        return self._values.get("start_canary_after_creation")
 
     @builtins.property
     def failure_retention_period(self) -> typing.Optional[jsii.Number]:
@@ -595,7 +760,7 @@ class CfnCanaryProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-synthetics-canary.html#cfn-synthetics-canary-failureretentionperiod
         """
-        return self._values.get('failure_retention_period')
+        return self._values.get("failure_retention_period")
 
     @builtins.property
     def success_retention_period(self) -> typing.Optional[jsii.Number]:
@@ -604,7 +769,7 @@ class CfnCanaryProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-synthetics-canary.html#cfn-synthetics-canary-successretentionperiod
         """
-        return self._values.get('success_retention_period')
+        return self._values.get("success_retention_period")
 
     @builtins.property
     def tags(self) -> typing.Optional[typing.List[_CfnTag_b4661f1a]]:
@@ -613,16 +778,20 @@ class CfnCanaryProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-synthetics-canary.html#cfn-synthetics-canary-tags
         """
-        return self._values.get('tags')
+        return self._values.get("tags")
 
     @builtins.property
-    def vpc_config(self) -> typing.Optional[typing.Union["CfnCanary.VPCConfigProperty", _IResolvable_9ceae33e]]:
+    def vpc_config(
+        self,
+    ) -> typing.Optional[
+        typing.Union["CfnCanary.VPCConfigProperty", _IResolvable_9ceae33e]
+    ]:
         """``AWS::Synthetics::Canary.VPCConfig``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-synthetics-canary.html#cfn-synthetics-canary-vpcconfig
         """
-        return self._values.get('vpc_config')
+        return self._values.get("vpc_config")
 
     def __eq__(self, rhs) -> bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -631,7 +800,9 @@ class CfnCanaryProps():
         return not (rhs == self)
 
     def __repr__(self) -> str:
-        return 'CfnCanaryProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+        return "CfnCanaryProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
 
 
 __all__ = [
