@@ -10,15 +10,31 @@ import publication
 
 from .._jsii import *
 
-from .. import (Construct as _Construct_f50a3f53, Reference as _Reference_d68b1ce5, Duration as _Duration_5170c158)
-from ..aws_cloudformation import (CustomResourceProviderConfig as _CustomResourceProviderConfig_8f2bd7a0, ICustomResourceProvider as _ICustomResourceProvider_6c6f53c6)
-from ..aws_iam import (IPrincipal as _IPrincipal_97126874, IGrantable as _IGrantable_0fcfc53a, PolicyStatement as _PolicyStatement_f75dc775, IRole as _IRole_e69bbae4)
-from ..aws_lambda import (IFunction as _IFunction_1c1de0bc)
-from ..aws_logs import (RetentionDays as _RetentionDays_bdc7ad1f)
+from .. import (
+    Construct as _Construct_f50a3f53,
+    Duration as _Duration_5170c158,
+    Reference as _Reference_d68b1ce5,
+)
+from ..aws_cloudformation import (
+    CustomResourceProviderConfig as _CustomResourceProviderConfig_8f2bd7a0,
+    ICustomResourceProvider as _ICustomResourceProvider_6c6f53c6,
+)
+from ..aws_iam import (
+    IRole as _IRole_e69bbae4,
+    IPrincipal as _IPrincipal_97126874,
+    IGrantable as _IGrantable_0fcfc53a,
+    PolicyStatement as _PolicyStatement_f75dc775,
+)
+from ..aws_lambda import IFunction as _IFunction_1c1de0bc
+from ..aws_logs import RetentionDays as _RetentionDays_bdc7ad1f
 
 
 @jsii.implements(_IGrantable_0fcfc53a)
-class AwsCustomResource(_Construct_f50a3f53, metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.custom_resources.AwsCustomResource"):
+class AwsCustomResource(
+    _Construct_f50a3f53,
+    metaclass=jsii.JSIIMeta,
+    jsii_type="monocdk-experiment.custom_resources.AwsCustomResource",
+):
     """Defines a custom resource that is materialized using specific AWS API calls.
 
     Use this to bridge any gap that might exist in the CloudFormation Coverage.
@@ -27,7 +43,21 @@ class AwsCustomResource(_Construct_f50a3f53, metaclass=jsii.JSIIMeta, jsii_type=
     stability
     :stability: experimental
     """
-    def __init__(self, scope: _Construct_f50a3f53, id: str, *, policy: "AwsCustomResourcePolicy", log_retention: typing.Optional[_RetentionDays_bdc7ad1f]=None, on_create: typing.Optional["AwsSdkCall"]=None, on_delete: typing.Optional["AwsSdkCall"]=None, on_update: typing.Optional["AwsSdkCall"]=None, resource_type: typing.Optional[str]=None, role: typing.Optional[_IRole_e69bbae4]=None, timeout: typing.Optional[_Duration_5170c158]=None) -> None:
+
+    def __init__(
+        self,
+        scope: _Construct_f50a3f53,
+        id: str,
+        *,
+        policy: "AwsCustomResourcePolicy",
+        log_retention: typing.Optional[_RetentionDays_bdc7ad1f] = None,
+        on_create: typing.Optional["AwsSdkCall"] = None,
+        on_delete: typing.Optional["AwsSdkCall"] = None,
+        on_update: typing.Optional["AwsSdkCall"] = None,
+        resource_type: typing.Optional[str] = None,
+        role: typing.Optional[_IRole_e69bbae4] = None,
+        timeout: typing.Optional[_Duration_5170c158] = None,
+    ) -> None:
         """
         :param scope: -
         :param id: -
@@ -43,7 +73,16 @@ class AwsCustomResource(_Construct_f50a3f53, metaclass=jsii.JSIIMeta, jsii_type=
         stability
         :stability: experimental
         """
-        props = AwsCustomResourceProps(policy=policy, log_retention=log_retention, on_create=on_create, on_delete=on_delete, on_update=on_update, resource_type=resource_type, role=role, timeout=timeout)
+        props = AwsCustomResourceProps(
+            policy=policy,
+            log_retention=log_retention,
+            on_create=on_create,
+            on_delete=on_delete,
+            on_update=on_update,
+            resource_type=resource_type,
+            role=role,
+            timeout=timeout,
+        )
 
         jsii.create(AwsCustomResource, self, [scope, id, props])
 
@@ -95,15 +134,21 @@ class AwsCustomResource(_Construct_f50a3f53, metaclass=jsii.JSIIMeta, jsii_type=
         return jsii.get(self, "grantPrincipal")
 
 
-class AwsCustomResourcePolicy(metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.custom_resources.AwsCustomResourcePolicy"):
+class AwsCustomResourcePolicy(
+    metaclass=jsii.JSIIMeta,
+    jsii_type="monocdk-experiment.custom_resources.AwsCustomResourcePolicy",
+):
     """The IAM Policy that will be applied to the different calls.
 
     stability
     :stability: experimental
     """
+
     @jsii.member(jsii_name="fromSdkCalls")
     @builtins.classmethod
-    def from_sdk_calls(cls, *, resources: typing.List[str]) -> "AwsCustomResourcePolicy":
+    def from_sdk_calls(
+        cls, *, resources: typing.List[str]
+    ) -> "AwsCustomResourcePolicy":
         """Generate IAM Policy Statements from the configured SDK calls.
 
         Each SDK call with be translated to an IAM Policy Statement in the form of: ``call.service:call.action`` (e.g ``s3:PutObject``).
@@ -119,7 +164,9 @@ class AwsCustomResourcePolicy(metaclass=jsii.JSIIMeta, jsii_type="monocdk-experi
 
     @jsii.member(jsii_name="fromStatements")
     @builtins.classmethod
-    def from_statements(cls, statements: typing.List[_PolicyStatement_f75dc775]) -> "AwsCustomResourcePolicy":
+    def from_statements(
+        cls, statements: typing.List[_PolicyStatement_f75dc775]
+    ) -> "AwsCustomResourcePolicy":
         """Explicit IAM Policy Statements.
 
         :param statements: the statements to propagate to the SDK calls.
@@ -160,9 +207,33 @@ class AwsCustomResourcePolicy(metaclass=jsii.JSIIMeta, jsii_type="monocdk-experi
         return jsii.get(self, "resources")
 
 
-@jsii.data_type(jsii_type="monocdk-experiment.custom_resources.AwsCustomResourceProps", jsii_struct_bases=[], name_mapping={'policy': 'policy', 'log_retention': 'logRetention', 'on_create': 'onCreate', 'on_delete': 'onDelete', 'on_update': 'onUpdate', 'resource_type': 'resourceType', 'role': 'role', 'timeout': 'timeout'})
-class AwsCustomResourceProps():
-    def __init__(self, *, policy: "AwsCustomResourcePolicy", log_retention: typing.Optional[_RetentionDays_bdc7ad1f]=None, on_create: typing.Optional["AwsSdkCall"]=None, on_delete: typing.Optional["AwsSdkCall"]=None, on_update: typing.Optional["AwsSdkCall"]=None, resource_type: typing.Optional[str]=None, role: typing.Optional[_IRole_e69bbae4]=None, timeout: typing.Optional[_Duration_5170c158]=None) -> None:
+@jsii.data_type(
+    jsii_type="monocdk-experiment.custom_resources.AwsCustomResourceProps",
+    jsii_struct_bases=[],
+    name_mapping={
+        "policy": "policy",
+        "log_retention": "logRetention",
+        "on_create": "onCreate",
+        "on_delete": "onDelete",
+        "on_update": "onUpdate",
+        "resource_type": "resourceType",
+        "role": "role",
+        "timeout": "timeout",
+    },
+)
+class AwsCustomResourceProps:
+    def __init__(
+        self,
+        *,
+        policy: "AwsCustomResourcePolicy",
+        log_retention: typing.Optional[_RetentionDays_bdc7ad1f] = None,
+        on_create: typing.Optional["AwsSdkCall"] = None,
+        on_delete: typing.Optional["AwsSdkCall"] = None,
+        on_update: typing.Optional["AwsSdkCall"] = None,
+        resource_type: typing.Optional[str] = None,
+        role: typing.Optional[_IRole_e69bbae4] = None,
+        timeout: typing.Optional[_Duration_5170c158] = None,
+    ) -> None:
         """Properties for AwsCustomResource.
 
         Note that at least onCreate, onUpdate or onDelete must be specified.
@@ -179,19 +250,29 @@ class AwsCustomResourceProps():
         stability
         :stability: experimental
         """
-        if isinstance(on_create, dict): on_create = AwsSdkCall(**on_create)
-        if isinstance(on_delete, dict): on_delete = AwsSdkCall(**on_delete)
-        if isinstance(on_update, dict): on_update = AwsSdkCall(**on_update)
+        if isinstance(on_create, dict):
+            on_create = AwsSdkCall(**on_create)
+        if isinstance(on_delete, dict):
+            on_delete = AwsSdkCall(**on_delete)
+        if isinstance(on_update, dict):
+            on_update = AwsSdkCall(**on_update)
         self._values = {
-            'policy': policy,
+            "policy": policy,
         }
-        if log_retention is not None: self._values["log_retention"] = log_retention
-        if on_create is not None: self._values["on_create"] = on_create
-        if on_delete is not None: self._values["on_delete"] = on_delete
-        if on_update is not None: self._values["on_update"] = on_update
-        if resource_type is not None: self._values["resource_type"] = resource_type
-        if role is not None: self._values["role"] = role
-        if timeout is not None: self._values["timeout"] = timeout
+        if log_retention is not None:
+            self._values["log_retention"] = log_retention
+        if on_create is not None:
+            self._values["on_create"] = on_create
+        if on_delete is not None:
+            self._values["on_delete"] = on_delete
+        if on_update is not None:
+            self._values["on_update"] = on_update
+        if resource_type is not None:
+            self._values["resource_type"] = resource_type
+        if role is not None:
+            self._values["role"] = role
+        if timeout is not None:
+            self._values["timeout"] = timeout
 
     @builtins.property
     def policy(self) -> "AwsCustomResourcePolicy":
@@ -209,7 +290,7 @@ class AwsCustomResourceProps():
         stability
         :stability: experimental
         """
-        return self._values.get('policy')
+        return self._values.get("policy")
 
     @builtins.property
     def log_retention(self) -> typing.Optional[_RetentionDays_bdc7ad1f]:
@@ -221,7 +302,7 @@ class AwsCustomResourceProps():
         stability
         :stability: experimental
         """
-        return self._values.get('log_retention')
+        return self._values.get("log_retention")
 
     @builtins.property
     def on_create(self) -> typing.Optional["AwsSdkCall"]:
@@ -233,7 +314,7 @@ class AwsCustomResourceProps():
         stability
         :stability: experimental
         """
-        return self._values.get('on_create')
+        return self._values.get("on_create")
 
     @builtins.property
     def on_delete(self) -> typing.Optional["AwsSdkCall"]:
@@ -245,7 +326,7 @@ class AwsCustomResourceProps():
         stability
         :stability: experimental
         """
-        return self._values.get('on_delete')
+        return self._values.get("on_delete")
 
     @builtins.property
     def on_update(self) -> typing.Optional["AwsSdkCall"]:
@@ -257,7 +338,7 @@ class AwsCustomResourceProps():
         stability
         :stability: experimental
         """
-        return self._values.get('on_update')
+        return self._values.get("on_update")
 
     @builtins.property
     def resource_type(self) -> typing.Optional[str]:
@@ -269,7 +350,7 @@ class AwsCustomResourceProps():
         stability
         :stability: experimental
         """
-        return self._values.get('resource_type')
+        return self._values.get("resource_type")
 
     @builtins.property
     def role(self) -> typing.Optional[_IRole_e69bbae4]:
@@ -285,7 +366,7 @@ class AwsCustomResourceProps():
         stability
         :stability: experimental
         """
-        return self._values.get('role')
+        return self._values.get("role")
 
     @builtins.property
     def timeout(self) -> typing.Optional[_Duration_5170c158]:
@@ -297,7 +378,7 @@ class AwsCustomResourceProps():
         stability
         :stability: experimental
         """
-        return self._values.get('timeout')
+        return self._values.get("timeout")
 
     def __eq__(self, rhs) -> bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -306,12 +387,38 @@ class AwsCustomResourceProps():
         return not (rhs == self)
 
     def __repr__(self) -> str:
-        return 'AwsCustomResourceProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+        return "AwsCustomResourceProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
 
 
-@jsii.data_type(jsii_type="monocdk-experiment.custom_resources.AwsSdkCall", jsii_struct_bases=[], name_mapping={'action': 'action', 'service': 'service', 'api_version': 'apiVersion', 'ignore_error_codes_matching': 'ignoreErrorCodesMatching', 'output_path': 'outputPath', 'parameters': 'parameters', 'physical_resource_id': 'physicalResourceId', 'region': 'region'})
-class AwsSdkCall():
-    def __init__(self, *, action: str, service: str, api_version: typing.Optional[str]=None, ignore_error_codes_matching: typing.Optional[str]=None, output_path: typing.Optional[str]=None, parameters: typing.Any=None, physical_resource_id: typing.Optional["PhysicalResourceId"]=None, region: typing.Optional[str]=None) -> None:
+@jsii.data_type(
+    jsii_type="monocdk-experiment.custom_resources.AwsSdkCall",
+    jsii_struct_bases=[],
+    name_mapping={
+        "action": "action",
+        "service": "service",
+        "api_version": "apiVersion",
+        "ignore_error_codes_matching": "ignoreErrorCodesMatching",
+        "output_path": "outputPath",
+        "parameters": "parameters",
+        "physical_resource_id": "physicalResourceId",
+        "region": "region",
+    },
+)
+class AwsSdkCall:
+    def __init__(
+        self,
+        *,
+        action: str,
+        service: str,
+        api_version: typing.Optional[str] = None,
+        ignore_error_codes_matching: typing.Optional[str] = None,
+        output_path: typing.Optional[str] = None,
+        parameters: typing.Any = None,
+        physical_resource_id: typing.Optional["PhysicalResourceId"] = None,
+        region: typing.Optional[str] = None,
+    ) -> None:
         """An AWS SDK call.
 
         :param action: The service action to call.
@@ -327,15 +434,21 @@ class AwsSdkCall():
         :stability: experimental
         """
         self._values = {
-            'action': action,
-            'service': service,
+            "action": action,
+            "service": service,
         }
-        if api_version is not None: self._values["api_version"] = api_version
-        if ignore_error_codes_matching is not None: self._values["ignore_error_codes_matching"] = ignore_error_codes_matching
-        if output_path is not None: self._values["output_path"] = output_path
-        if parameters is not None: self._values["parameters"] = parameters
-        if physical_resource_id is not None: self._values["physical_resource_id"] = physical_resource_id
-        if region is not None: self._values["region"] = region
+        if api_version is not None:
+            self._values["api_version"] = api_version
+        if ignore_error_codes_matching is not None:
+            self._values["ignore_error_codes_matching"] = ignore_error_codes_matching
+        if output_path is not None:
+            self._values["output_path"] = output_path
+        if parameters is not None:
+            self._values["parameters"] = parameters
+        if physical_resource_id is not None:
+            self._values["physical_resource_id"] = physical_resource_id
+        if region is not None:
+            self._values["region"] = region
 
     @builtins.property
     def action(self) -> str:
@@ -346,7 +459,7 @@ class AwsSdkCall():
         stability
         :stability: experimental
         """
-        return self._values.get('action')
+        return self._values.get("action")
 
     @builtins.property
     def service(self) -> str:
@@ -357,7 +470,7 @@ class AwsSdkCall():
         stability
         :stability: experimental
         """
-        return self._values.get('service')
+        return self._values.get("service")
 
     @builtins.property
     def api_version(self) -> typing.Optional[str]:
@@ -371,7 +484,7 @@ class AwsSdkCall():
         stability
         :stability: experimental
         """
-        return self._values.get('api_version')
+        return self._values.get("api_version")
 
     @builtins.property
     def ignore_error_codes_matching(self) -> typing.Optional[str]:
@@ -387,7 +500,7 @@ class AwsSdkCall():
         stability
         :stability: experimental
         """
-        return self._values.get('ignore_error_codes_matching')
+        return self._values.get("ignore_error_codes_matching")
 
     @builtins.property
     def output_path(self) -> typing.Optional[str]:
@@ -405,7 +518,7 @@ class AwsSdkCall():
         stability
         :stability: experimental
         """
-        return self._values.get('output_path')
+        return self._values.get("output_path")
 
     @builtins.property
     def parameters(self) -> typing.Any:
@@ -419,7 +532,7 @@ class AwsSdkCall():
         stability
         :stability: experimental
         """
-        return self._values.get('parameters')
+        return self._values.get("parameters")
 
     @builtins.property
     def physical_resource_id(self) -> typing.Optional["PhysicalResourceId"]:
@@ -433,7 +546,7 @@ class AwsSdkCall():
         stability
         :stability: experimental
         """
-        return self._values.get('physical_resource_id')
+        return self._values.get("physical_resource_id")
 
     @builtins.property
     def region(self) -> typing.Optional[str]:
@@ -448,7 +561,7 @@ class AwsSdkCall():
         stability
         :stability: experimental
         """
-        return self._values.get('region')
+        return self._values.get("region")
 
     def __eq__(self, rhs) -> bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -457,15 +570,21 @@ class AwsSdkCall():
         return not (rhs == self)
 
     def __repr__(self) -> str:
-        return 'AwsSdkCall(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+        return "AwsSdkCall(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
 
 
-class PhysicalResourceId(metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.custom_resources.PhysicalResourceId"):
+class PhysicalResourceId(
+    metaclass=jsii.JSIIMeta,
+    jsii_type="monocdk-experiment.custom_resources.PhysicalResourceId",
+):
     """Physical ID of the custom resource.
 
     stability
     :stability: experimental
     """
+
     @jsii.member(jsii_name="fromResponse")
     @builtins.classmethod
     def from_response(cls, response_path: str) -> "PhysicalResourceId":
@@ -512,13 +631,27 @@ class PhysicalResourceId(metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.
 
 
 @jsii.implements(_ICustomResourceProvider_6c6f53c6)
-class Provider(_Construct_f50a3f53, metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.custom_resources.Provider"):
+class Provider(
+    _Construct_f50a3f53,
+    metaclass=jsii.JSIIMeta,
+    jsii_type="monocdk-experiment.custom_resources.Provider",
+):
     """Defines an AWS CloudFormation custom resource provider.
 
     stability
     :stability: experimental
     """
-    def __init__(self, scope: _Construct_f50a3f53, id: str, *, on_event_handler: _IFunction_1c1de0bc, is_complete_handler: typing.Optional[_IFunction_1c1de0bc]=None, query_interval: typing.Optional[_Duration_5170c158]=None, total_timeout: typing.Optional[_Duration_5170c158]=None) -> None:
+
+    def __init__(
+        self,
+        scope: _Construct_f50a3f53,
+        id: str,
+        *,
+        on_event_handler: _IFunction_1c1de0bc,
+        is_complete_handler: typing.Optional[_IFunction_1c1de0bc] = None,
+        query_interval: typing.Optional[_Duration_5170c158] = None,
+        total_timeout: typing.Optional[_Duration_5170c158] = None,
+    ) -> None:
         """
         :param scope: -
         :param id: -
@@ -530,7 +663,12 @@ class Provider(_Construct_f50a3f53, metaclass=jsii.JSIIMeta, jsii_type="monocdk-
         stability
         :stability: experimental
         """
-        props = ProviderProps(on_event_handler=on_event_handler, is_complete_handler=is_complete_handler, query_interval=query_interval, total_timeout=total_timeout)
+        props = ProviderProps(
+            on_event_handler=on_event_handler,
+            is_complete_handler=is_complete_handler,
+            query_interval=query_interval,
+            total_timeout=total_timeout,
+        )
 
         jsii.create(Provider, self, [scope, id, props])
 
@@ -579,9 +717,25 @@ class Provider(_Construct_f50a3f53, metaclass=jsii.JSIIMeta, jsii_type="monocdk-
         return jsii.get(self, "isCompleteHandler")
 
 
-@jsii.data_type(jsii_type="monocdk-experiment.custom_resources.ProviderProps", jsii_struct_bases=[], name_mapping={'on_event_handler': 'onEventHandler', 'is_complete_handler': 'isCompleteHandler', 'query_interval': 'queryInterval', 'total_timeout': 'totalTimeout'})
-class ProviderProps():
-    def __init__(self, *, on_event_handler: _IFunction_1c1de0bc, is_complete_handler: typing.Optional[_IFunction_1c1de0bc]=None, query_interval: typing.Optional[_Duration_5170c158]=None, total_timeout: typing.Optional[_Duration_5170c158]=None) -> None:
+@jsii.data_type(
+    jsii_type="monocdk-experiment.custom_resources.ProviderProps",
+    jsii_struct_bases=[],
+    name_mapping={
+        "on_event_handler": "onEventHandler",
+        "is_complete_handler": "isCompleteHandler",
+        "query_interval": "queryInterval",
+        "total_timeout": "totalTimeout",
+    },
+)
+class ProviderProps:
+    def __init__(
+        self,
+        *,
+        on_event_handler: _IFunction_1c1de0bc,
+        is_complete_handler: typing.Optional[_IFunction_1c1de0bc] = None,
+        query_interval: typing.Optional[_Duration_5170c158] = None,
+        total_timeout: typing.Optional[_Duration_5170c158] = None,
+    ) -> None:
         """Initialization properties for the ``Provider`` construct.
 
         :param on_event_handler: The AWS Lambda function to invoke for all resource lifecycle operations (CREATE/UPDATE/DELETE). This function is responsible to begin the requested resource operation (CREATE/UPDATE/DELETE) and return any additional properties to add to the event, which will later be passed to ``isComplete``. The ``PhysicalResourceId`` property must be included in the response.
@@ -593,11 +747,14 @@ class ProviderProps():
         :stability: experimental
         """
         self._values = {
-            'on_event_handler': on_event_handler,
+            "on_event_handler": on_event_handler,
         }
-        if is_complete_handler is not None: self._values["is_complete_handler"] = is_complete_handler
-        if query_interval is not None: self._values["query_interval"] = query_interval
-        if total_timeout is not None: self._values["total_timeout"] = total_timeout
+        if is_complete_handler is not None:
+            self._values["is_complete_handler"] = is_complete_handler
+        if query_interval is not None:
+            self._values["query_interval"] = query_interval
+        if total_timeout is not None:
+            self._values["total_timeout"] = total_timeout
 
     @builtins.property
     def on_event_handler(self) -> _IFunction_1c1de0bc:
@@ -611,7 +768,7 @@ class ProviderProps():
         stability
         :stability: experimental
         """
-        return self._values.get('on_event_handler')
+        return self._values.get("on_event_handler")
 
     @builtins.property
     def is_complete_handler(self) -> typing.Optional[_IFunction_1c1de0bc]:
@@ -631,7 +788,7 @@ class ProviderProps():
         stability
         :stability: experimental
         """
-        return self._values.get('is_complete_handler')
+        return self._values.get("is_complete_handler")
 
     @builtins.property
     def query_interval(self) -> typing.Optional[_Duration_5170c158]:
@@ -647,7 +804,7 @@ class ProviderProps():
         stability
         :stability: experimental
         """
-        return self._values.get('query_interval')
+        return self._values.get("query_interval")
 
     @builtins.property
     def total_timeout(self) -> typing.Optional[_Duration_5170c158]:
@@ -661,7 +818,7 @@ class ProviderProps():
         stability
         :stability: experimental
         """
-        return self._values.get('total_timeout')
+        return self._values.get("total_timeout")
 
     def __eq__(self, rhs) -> bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -670,11 +827,17 @@ class ProviderProps():
         return not (rhs == self)
 
     def __repr__(self) -> str:
-        return 'ProviderProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+        return "ProviderProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
 
 
-@jsii.data_type(jsii_type="monocdk-experiment.custom_resources.SdkCallsPolicyOptions", jsii_struct_bases=[], name_mapping={'resources': 'resources'})
-class SdkCallsPolicyOptions():
+@jsii.data_type(
+    jsii_type="monocdk-experiment.custom_resources.SdkCallsPolicyOptions",
+    jsii_struct_bases=[],
+    name_mapping={"resources": "resources"},
+)
+class SdkCallsPolicyOptions:
     def __init__(self, *, resources: typing.List[str]) -> None:
         """Options for the auto-generation of policies based on the configured SDK calls.
 
@@ -684,7 +847,7 @@ class SdkCallsPolicyOptions():
         :stability: experimental
         """
         self._values = {
-            'resources': resources,
+            "resources": resources,
         }
 
     @builtins.property
@@ -700,7 +863,7 @@ class SdkCallsPolicyOptions():
         stability
         :stability: experimental
         """
-        return self._values.get('resources')
+        return self._values.get("resources")
 
     def __eq__(self, rhs) -> bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -709,7 +872,9 @@ class SdkCallsPolicyOptions():
         return not (rhs == self)
 
     def __repr__(self) -> str:
-        return 'SdkCallsPolicyOptions(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+        return "SdkCallsPolicyOptions(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
 
 
 __all__ = [
